"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_path_1 = __importDefault(require("node:path"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const glob_1 = __importDefault(require("glob"));
const less_1 = __importDefault(require("less"));
const vite_1 = require("vite");
const vite_material_prod_1 = __importDefault(require("../../configs/vite.material.prod"));
const vite_material_style_1 = __importDefault(require("../../configs/vite.material.style"));
const config_1 = require("../../utils/config");
const get_package_1 = require("../../utils/get-package");
function buildLess() {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            // 存在style.css时，将其移动到css目录
            yield fs_extra_1.default.access('dist/style.css');
            fs_extra_1.default.moveSync('dist/style.css', 'dist/css/index.css');
        }
        catch (_a) {
            // 不存在产物时，通过index.less构建
            const lessContent = fs_extra_1.default.readFileSync('src/style/index.less', 'utf8');
            less_1.default.render(lessContent, { paths: [node_path_1.default.resolve(process.cwd(), 'src')] }, (err, result) => {
                if (err) {
                    console.log(err);
                }
                else if (result && result.css) {
                    fs_extra_1.default.writeFileSync('dist/css/index.css', result.css);
                }
            });
        }
    });
}
function buildStyle() {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        fs_extra_1.default.ensureDirSync('dist/css');
        yield buildLess();
        // 编译less文件入口
        yield (0, vite_1.build)(vite_material_style_1.default);
        // 复制less文件到dist/css目录下
        const lessFiles = glob_1.default.sync('src/style/**/*.less');
        for (const file of lessFiles) {
            const filename = (_a = file.match(/src\/style\/(.*)/)) === null || _a === void 0 ? void 0 : _a[1];
            fs_extra_1.default.copyFileSync(file, `dist/css/${filename}`);
        }
    });
}
function run(buildInput) {
    var _a, _b, _c, _d;
    return __awaiter(this, void 0, void 0, function* () {
        const packageData = yield (0, get_package_1.getPackage)();
        const input = (_a = packageData.buildInput) !== null && _a !== void 0 ? _a : buildInput;
        const name = (_c = (_b = packageData.umd) === null || _b === void 0 ? void 0 : _b.module) !== null && _c !== void 0 ? _c : 'DigitMaterial';
        const baseConfig = (0, vite_material_prod_1.default)({ input, name });
        const userConfig = yield (0, config_1.getUserConfig)('vite.config.js');
        const mergedConfig = (_d = userConfig === null || userConfig === void 0 ? void 0 : userConfig(baseConfig)) !== null && _d !== void 0 ? _d : baseConfig;
        yield (0, vite_1.build)(mergedConfig);
        // todo: 后续升级 style的构建方式
        yield buildStyle();
    });
}
exports.default = run;
//# sourceMappingURL=index.js.map